@@ -1,14 +1,12 @@
-( cd usr/share/doc/HTML/el/sweeper ; rm -rf common )
-( cd usr/share/doc/HTML/el/sweeper ; ln -sf /usr/share/doc/HTML/el//common common )
-( cd usr/share/doc/HTML/el/onlinehelp ; rm -rf common )
-( cd usr/share/doc/HTML/el/onlinehelp ; ln -sf /usr/share/doc/HTML/el//common common )
-( cd usr/share/doc/HTML/el/printer-applet ; rm -rf common )
-( cd usr/share/doc/HTML/el/printer-applet ; ln -sf /usr/share/doc/HTML/el//common common )
-( cd usr/share/doc/HTML/el/kcharselect ; rm -rf common )
-( cd usr/share/doc/HTML/el/kcharselect ; ln -sf /usr/share/doc/HTML/el//common common )
-( cd usr/share/doc/HTML/el/khelpcenter/documentationnotfound ; rm -rf common )
-( cd usr/share/doc/HTML/el/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/el//common common )
-( cd usr/share/doc/HTML/el/plasma-desktop ; rm -rf common )
-( cd usr/share/doc/HTML/el/plasma-desktop ; ln -sf /usr/share/doc/HTML/el//common common )
 ( cd usr/share/doc/HTML/el/konqueror ; rm -rf common )
 ( cd usr/share/doc/HTML/el/konqueror ; ln -sf /usr/share/doc/HTML/el//common common )
+( cd usr/share/doc/HTML/el/sweeper ; rm -rf common )
+( cd usr/share/doc/HTML/el/sweeper ; ln -sf /usr/share/doc/HTML/el//common common )
+( cd usr/share/doc/HTML/el/kcharselect ; rm -rf common )
+( cd usr/share/doc/HTML/el/kcharselect ; ln -sf /usr/share/doc/HTML/el//common common )
+( cd usr/share/doc/HTML/el/plasma-desktop ; rm -rf common )
+( cd usr/share/doc/HTML/el/plasma-desktop ; ln -sf /usr/share/doc/HTML/el//common common )
+( cd usr/share/doc/HTML/el/onlinehelp ; rm -rf common )
+( cd usr/share/doc/HTML/el/onlinehelp ; ln -sf /usr/share/doc/HTML/el//common common )
+( cd usr/share/doc/HTML/el/khelpcenter/documentationnotfound ; rm -rf common )
+( cd usr/share/doc/HTML/el/khelpcenter/documentationnotfound ; ln -sf /usr/share/doc/HTML/el//common common )
